==> peperit_2.0_estable.zip: themes/peperit/html_files/componentes/cesta/trozos_cesta_completa/trozos_cesta_completa_direcciones.php <==
<?php
//Pedro 03/Abril/2019 ==> este script muestra todo lo necesario para que el cliente haga login en la cesta:
//Vamos a obtener al usuario, en este caso nos da igual que esté logueado o que sea un usuarioSinRegistro

//para poder usar el widget helper:
include('comunes/globals.php');
$usuario = Usuario::logueado();
?>
<div class="col-xs-12 trozos_cesta_completa_direcciones">
	<?php
		//apartado usuario
	?>
	<div class="col-xs-12 apartado_usuario borde_contenedor">
		<div class="titulo_contenedor"><h3 class="paso1_cesta_logueado"><span class="paso_1"><strong><?=traducir('1');?></strong><?=traducir('Te has identificado');?></span></h3></div>
		<div class="col-xs-8 datos_usu">
			<p class="titular">
				<i class="mdi mdi-account-outline"></i>
				<span><?=$usuario->nombre_comercial;?></span>
			</p>
			<p class="titular">
				<i class="mdi mdi-email-outline"></i>
				<span><?=$usuario->email;?></span>
			</p>
		</div>
		<div class="col-xs-4 boton_nosoy">
			<p class="subtitulo"><?=traducir('¿No eres tú?')?></p>
			<form action="<?=Shop::$configuracion->url;?>cesta" method="post">
				<?= Module::insertActionController('login', 'cartLogout'); ?>
				<button type="submit" name="continuar" class="boton button-medium">
					<span><?=traducir('Cambiar de usuario')?></span>
				</button>
			</form>
		</div>
	</div>
	<?php
		//Direcciones de envío
	?>
	<div id="seccion_direcciones" class="col-xs-12 borde_contenedor collapse in seccion_direcciones">
		<div class="titulo_contenedor"><h3 class="paso2_cesta"><span class="paso_2"><strong><?=traducir('2');?></strong><?=traducir('Dirección y envío');?></span></h3></div>
		<ul class="nav nav-tabs">
		  <?php
		  //OJO, si tenemos envío recogida en tienda, mostramos esto:
		  if (Shop::$configuracion->envio_recogida_tienda > 0){
			  ?>
			  <li onclick="
				var data = {'tipo_envio' : 0};
				WS_data_update(
					'CabeceraCesta',
					'setShippingType',
					data,
					'*=\'bloque_tipo_envio\'|*=\'bloque_total_cesta\'',
					function(objeto){

					}
				);	
				" class="active"><a data-toggle="tab" href="#domicilio"><?=traducir('ENVÍO A DOMICILIO');?></a></li>
			  <li onclick="
				var data = {'tipo_envio' : <?=Shop::$configuracion->envio_recogida_tienda?>};
				WS_data_update(
					'CabeceraCesta',
					'setShippingType',
					data,
					'*=\'bloque_tipo_envio\'|*=\'bloque_total_cesta\'',
					function(objeto){

					}
				);	
				"><a data-toggle="tab" href="#recoger"><?=traducir('RECOGIDA EN TIENDA');?></a></li>
			  <?php
		  }else{
			 ?>
			<li class="active"><a data-toggle="tab" href="#domicilio"><?=traducir('ENVÍO A DOMICILIO');?></a></li>
			 <?php
		  }
		  ?>
		</ul>

		<div class="tab-content">
			<div id="domicilio" class="tab-pane fade in active">
				<?php
				//Empezamos con el formulario de dirección de envío:
				//$datosDireccion = CabeceraCesta::getShippingDestination();
				$opciones = new ObOptions(array(
							'fichero_direccion' => 'direccion_envio_formulario',
							'dataUpdate' => 'bloque_direccion_envio'
				));
				new Widget($_WH->GW('direcciones_envio'), $opciones);
				
					//SIEMPRE mostraremos un formulario con la dirección a la que se va a enviar y debajo el selector de direcciones
					//El formulario contendrá la dirección por defecto
					//Debajo no habrá direcciones si no hay más
					//Si el usuario está registrado aparece el botón para añadir una dirección
					//Necesitamos por tanto estos componentes:
						// ==> Formulario con los datos de envío
						// ==> selector de dirección de envío
					//Estos controles tengo que lanzarlos desde un widget para que este se pueda actualizar dinámicamente
					//En la cesta vamos a añdir un control que es el encargado de hacer el submit de cualquier fomulario que tengamos seleccioado
					//TODO ==> Aquí mostramos la opción para crear/seleccionar otra dirección de envío distita
				?>
				<div class="seleccion_tipo_envio">
					<?php
					//Hay que modificar este widget para que no muestre el contenido si no está correcta la dirección de envío:
					$opciones = array('tipo' => 'perso', 'fichero_linea_tipo_envio' => 'linea_tipo_envio', 'dataUpdate' => 'bloque_tipo_envio');
					new Widget($_WH->GW('cesta_compra', 'selector_tipo_envio'), $opciones);
					?>
				</div>
			</div>
			<div id="recoger" class="tab-pane fade">
				<div class="recoger_en_tienda">
					<div class="ok_recoger"><span><?=traducir('¡De acuerdo!');?></span></div>
					<div class="texto_recoger">
						<h5 class="titular">
						<?=traducir('Recogerá su pedido en nuestra tienda ubicada en: ');?></h5>
						<div class="titular_direccion">
							<p class="direccion_recogida"><?=Shop::$empresa->direccion;?> - </p>
							<p class="postal_recogida">(<?=Shop::$empresa->cod_postal;?>) </p>
							<p class="localidad_recogida"><?=Shop::$empresa->localidad;?></p>

							<?php
							//Si la localidad y la provincia son iguales muestro solo la localidad
							$localidad=Shop::$empresa->localidad;
							$provincia=Shop::$empresa->provincia;

							if(strnatcasecmp($provincia,$localidad) != 0){
							?>
								<p class="provincia_recogida"> - <?=Shop::$empresa->provincia;?></p>
							<?php
							}
							?>
							<a href="<?=Shop::$configuracion->url;?>/conocenos" class="enlace_ver_mapa"><?=traducir('Ver en el mapa')?></a>
						</div>
					</div>
				</div>
			</div>

		</div>
	</div>
	

	
	<?php
		//Forma de pago
	?>
	<div class="seleccion_forma_pago">
		
			<?php
			$opciones = array('tipo' => 'perso', 'dataUpdate' => 'bloque_tipo_envio');
			new Widget($_WH->GW('cesta_compra', 'selector_forma_pago'), $opciones);
			?>
	</div>
</div>

==> peperit_2.1_estable.zip: themes/peperit/html_files/componentes/cesta/trozos_cesta_completa/trozos_cesta_completa_direcciones.php <==
<?php
//Pedro 03/Abril/2019 ==> este script muestra todo lo necesario para que el cliente haga login en la cesta:
//Vamos a obtener al usuario, en este caso nos da igual que esté logueado o que sea un usuarioSinRegistro

//para poder usar el widget helper:
include('comunes/globals.php');
$usuario = Usuario::logueado();
$classTabTipoEnvio='in active';
?>
<div class="col-xs-12 trozos_cesta_completa_direcciones">
	<?php
		//apartado usuario
	?>
	<div class="col-xs-12 apartado_usuario borde_contenedor">
		<div class="titulo_contenedor"><h3 class="paso1_cesta_logueado"><span class="paso_1"><strong><?=traducir('1');?></strong><?=traducir('Te has identificado');?></span></h3></div>
		<div class="col-xs-8 datos_usu">
			<p class="titular">
				<i class="mdi mdi-account-outline"></i>
				<span><?=$usuario->nombre_comercial;?></span>
			</p>
			<p class="titular">
				<i class="mdi mdi-email-outline"></i>
				<span><?=$usuario->email;?></span>
			</p>
		</div>
		<div class="col-xs-4 boton_nosoy">
			<p class="subtitulo"><?=traducir('¿No eres tú?')?></p>
			<form action="<?=Shop::$configuracion->url;?>cesta" method="post">
				<?= Module::insertActionController('login', 'cartLogout'); ?>
				<button type="submit" name="continuar" class="boton button-medium">
					<span><?=traducir('Cambiar de usuario')?></span>
				</button>
			</form>
		</div>
	</div>
	<?php
		//Direcciones de envío
	?>
	<div id="seccion_direcciones" class="col-xs-12 borde_contenedor collapse in seccion_direcciones">
		<div class="titulo_contenedor"><h3 class="paso2_cesta"><span class="paso_2"><strong><?=traducir('2');?></strong><?=traducir('Dirección y envío');?></span></h3></div>
		<ul class="nav nav-tabs">
		  <?php
		  //OJO, si tenemos envío recogida en tienda, mostramos esto:
		  if (Shop::$configuracion->envio_recogida_tienda > 0){
			  //Pedro 27/Julio/2020 ==> Si tenemos seleccionado el tipo de envío "recogida en tienda" establecido en configuración, mostramos esta pestaña
			  //Vamos a dejar marcado el tipo de envío (si procede)
			  $tipo_envio = CabeceraCesta::getShippingType(true);	//==> Cogemos el tipo de envío de la cesta
			  $recogidaTienda = $tipo_envio->sin_envio;
			  $classTipoEnvio = ($recogidaTienda) ? '' : 'active';
			  $classTipoDomincilio = ($recogidaTienda) ? 'active' : '';
			  $classTabTipoEnvio = ($recogidaTienda) ? '' : 'in active';
			  $classTabTipoDomincilio = ($recogidaTienda) ? 'in active' : '';
			  ?>
			  <li onclick="
				var data = {'tipo_envio' : 0};
				WS_data_update(
					'CabeceraCesta',
					'setShippingType',
					data,
					'*=\'bloque_tipo_envio\'|*=\'bloque_total_cesta\'',
					function(objeto){

					}
				);	
				" class="<?=$classTipoEnvio;?>"><a data-toggle="tab" href="#domicilio"><?=traducir('ENVÍO A DOMICILIO');?></a></li>
			  <li onclick="
				var data = {'tipo_envio' : <?=Shop::$configuracion->envio_recogida_tienda?>};
				WS_data_update(
					'CabeceraCesta',
					'setShippingType',
					data,
					'*=\'bloque_tipo_envio\'|*=\'bloque_total_cesta\'',
					function(objeto){

					}
				);	
				" class ="<?=$classTipoDomincilio;?>"><a data-toggle="tab" href="#recoger"><?=traducir('RECOGIDA EN TIENDA');?></a></li>
			  <?php
		  }else{
			 ?>
			<li class="active"><a data-toggle="tab" href="#domicilio"><?=traducir('ENVÍO A DOMICILIO');?></a></li>
			 <?php
		  }
		  ?>
		</ul>

		<div class="tab-content">
			<div id="domicilio" class="tab-pane fade <?=$classTabTipoEnvio;?>">
				<?php
				//Empezamos con el formulario de dirección de envío:
				//$datosDireccion = CabeceraCesta::getShippingDestination();
				$opciones = new ObOptions(array(
							'fichero_direccion' => 'direccion_envio_formulario',
							'dataUpdate' => 'bloque_direccion_envio'
				));
				new Widget($_WH->GW('direcciones_envio'), $opciones);
				
					//SIEMPRE mostraremos un formulario con la dirección a la que se va a enviar y debajo el selector de direcciones
					//El formulario contendrá la dirección por defecto
					//Debajo no habrá direcciones si no hay más
					//Si el usuario está registrado aparece el botón para añadir una dirección
					//Necesitamos por tanto estos componentes:
						// ==> Formulario con los datos de envío
						// ==> selector de dirección de envío
					//Estos controles tengo que lanzarlos desde un widget para que este se pueda actualizar dinámicamente
					//En la cesta vamos a añdir un control que es el encargado de hacer el submit de cualquier fomulario que tengamos seleccioado
					//TODO ==> Aquí mostramos la opción para crear/seleccionar otra dirección de envío distita
				?>
				<div class="seleccion_tipo_envio">
					<?php
					//Hay que modificar este widget para que no muestre el contenido si no está correcta la dirección de envío:
					$opciones = array('tipo' => 'perso', 'fichero_linea_tipo_envio' => 'linea_tipo_envio', 'dataUpdate' => 'bloque_tipo_envio');
					new Widget($_WH->GW('cesta_compra', 'selector_tipo_envio'), $opciones);
					?>
				</div>
			</div>
			<div id="recoger" class="tab-pane fade <?=$classTabTipoDomincilio;?>">
				<div class="recoger_en_tienda">
					<div class="ok_recoger"><span><?=traducir('¡De acuerdo!');?></span></div>
					<div class="texto_recoger">
						<h5 class="titular">
						<?=traducir('Recogerá su pedido en nuestra tienda ubicada en: ');?></h5>
						<div class="titular_direccion">
							<p class="direccion_recogida"><?=Shop::$empresa->direccion;?> - </p>
							<p class="postal_recogida">(<?=Shop::$empresa->cod_postal;?>) </p>
							<p class="localidad_recogida"><?=Shop::$empresa->localidad;?></p>

							<?php
							//Si la localidad y la provincia son iguales muestro solo la localidad
							$localidad=Shop::$empresa->localidad;
							$provincia=Shop::$empresa->provincia;

							if(strnatcasecmp($provincia,$localidad) != 0){
							?>
								<p class="provincia_recogida"> - <?=Shop::$empresa->provincia;?></p>
							<?php
							}
							?>
							<a href="<?=Shop::$configuracion->url;?>/conocenos" class="enlace_ver_mapa"><?=traducir('Ver en el mapa')?></a>
						</div>
					</div>
				</div>
			</div>

		</div>
	</div>
	

	
	<?php
		//Forma de pago
	?>
	<div class="seleccion_forma_pago">
		
			<?php
			$opciones = array('tipo' => 'perso', 'dataUpdate' => 'bloque_tipo_envio');
			new Widget($_WH->GW('cesta_compra', 'selector_forma_pago'), $opciones);
			?>
	</div>
</div>
